# Generated by roxygen2: do not edit by hand

export(BFVParams)
export(BGVParams)
export(BinFHEMethod)
export(BinFHEOutput)
export(BinFHEParamSet)
export(BinGate)
export(CKKSDataType)
export(CKKSParams)
export(Ciphertext)
export(CompressionLevel)
export(CryptoContext)
export(CryptoParameters)
export(DecryptionNoiseMode)
export(DistributionType)
export(ElementParams)
export(EncodingParams)
export(EncryptionTechnique)
export(EvalKey)
export(EvalKeyMap)
export(ExecutionMode)
export(FastRotationPrecomputation)
export(Feature)
export(KeyPair)
export(KeySwitchTechnique)
export(KeygenMode)
export(LWECiphertext)
export(LWEPrivateKey)
export(MultipartyMode)
export(MultiplicationTechnique)
export(OpenFHEObject)
export(PREMode)
export(Plaintext)
export(PlaintextEncodings)
export(PrivateKey)
export(PublicKey)
export(ScalingTechnique)
export(SchemeId)
export(SecretKeyDist)
export(SecretShareMap)
export(SecurityLevel)
export(bin_bt_key_gen)
export(bin_decrypt)
export(bin_encrypt)
export(bin_fhe_context)
export(bin_key_gen)
export(ckks_scaling_factor_bits)
export(clear_eval_automorphism_keys)
export(clear_eval_mult_keys)
export(clear_fhe_state)
export(clear_static_maps_and_vectors)
export(compress)
export(decrypt)
export(deserialize_eval_keys)
export(enable_feature)
export(encrypt)
export(eval_add)
export(eval_add_in_place)
export(eval_add_mutable)
export(eval_at_index_key_gen)
export(eval_automorphism)
export(eval_automorphism_key_gen)
export(eval_bin_gate)
export(eval_bootstrap)
export(eval_bootstrap_key_gen)
export(eval_bootstrap_setup)
export(eval_chebyshev)
export(eval_chebyshev_coefficients)
export(eval_chebyshev_function)
export(eval_chebyshev_linear)
export(eval_chebyshev_ps)
export(eval_cos)
export(eval_divide)
export(eval_fast_rotation)
export(eval_fast_rotation_ext)
export(eval_fast_rotation_precompute)
export(eval_floor)
export(eval_func)
export(eval_logistic)
export(eval_mult)
export(eval_mult_and_relinearize)
export(eval_mult_in_place)
export(eval_mult_key_gen)
export(eval_mult_mutable)
export(eval_mult_no_relin)
export(eval_negate)
export(eval_negate_in_place)
export(eval_not)
export(eval_poly)
export(eval_poly_linear)
export(eval_poly_ps)
export(eval_rotate)
export(eval_rotate_key_gen)
export(eval_sign)
export(eval_sin)
export(eval_square)
export(eval_square_mutable)
export(eval_sub)
export(eval_sub_in_place)
export(eval_sub_mutable)
export(eval_sum)
export(eval_sum_key_gen)
export(fhe_ckks_tolerance)
export(fhe_context)
export(fhe_deserialize)
export(fhe_serialize)
export(find_automorphism_index)
export(find_automorphism_indices)
export(generate_lut_via_function)
export(get_all_eval_automorphism_keys)
export(get_all_eval_mult_keys)
export(get_all_eval_sum_keys)
export(get_batch_size)
export(get_bootstrap_depth)
export(get_ckks_boot_correction_factor)
export(get_ckks_data_type)
export(get_coef_packed_value)
export(get_complex_packed_value)
export(get_composite_degree)
export(get_crypto_context)
export(get_crypto_parameters)
export(get_cyclotomic_order)
export(get_decryption_noise_mode)
export(get_desired_precision)
export(get_digit_size)
export(get_element_params)
export(get_element_ring_dimension)
export(get_encoding_params)
export(get_encoding_type)
export(get_encryption_technique)
export(get_eval_add_count)
export(get_eval_automorphism_key_map)
export(get_eval_mult_key_vector)
export(get_eval_sum_key_map)
export(get_execution_mode)
export(get_first_mod_size)
export(get_formatted_values)
export(get_interactive_boot_compression_level)
export(get_key_gen_level)
export(get_key_switch_count)
export(get_key_switch_technique)
export(get_key_tag)
export(get_length)
export(get_level)
export(get_log_error)
export(get_log_precision)
export(get_max_plaintext_space)
export(get_max_relin_sk_deg)
export(get_multiparty_mode)
export(get_multiplication_technique)
export(get_multiplicative_depth)
export(get_native_int)
export(get_noise_estimate)
export(get_noise_scale_deg)
export(get_num_adversarial_queries)
export(get_num_large_digits)
export(get_num_threads)
export(get_packed_value)
export(get_plaintext_modulus)
export(get_pre_mode)
export(get_pre_num_hops)
export(get_real_packed_value)
export(get_register_word_size)
export(get_ring_dim)
export(get_scaling_factor)
export(get_scaling_factor_int)
export(get_scaling_factor_real)
export(get_scaling_mod_size)
export(get_scaling_technique)
export(get_scheme)
export(get_scheme_id)
export(get_secret_key_dist)
export(get_security_level)
export(get_slots)
export(get_standard_deviation)
export(get_statistical_security)
export(get_string_value)
export(get_threshold_num_of_parties)
export(high_bound)
export(insert_eval_automorphism_key)
export(insert_eval_mult_key)
export(insert_eval_sum_key)
export(int_boot_add)
export(int_boot_adjust_scale)
export(int_boot_decrypt)
export(int_boot_encrypt)
export(int_mp_boot_add)
export(int_mp_boot_adjust_scale)
export(int_mp_boot_decrypt)
export(int_mp_boot_encrypt)
export(int_mp_boot_random_element_gen)
export(is_encoded)
export(is_good)
export(key_gen)
export(key_switch_down)
export(level_reduce)
export(level_reduce_in_place)
export(low_bound)
export(make_ckks_packed_plaintext)
export(make_coef_packed_plaintext)
export(make_packed_plaintext)
export(mod_reduce)
export(mod_reduce_in_place)
export(multi_add_eval_automorphism_keys)
export(multi_add_eval_keys)
export(multi_add_eval_mult_keys)
export(multi_add_eval_sum_keys)
export(multi_add_pub_keys)
export(multi_eval_at_index_key_gen)
export(multi_eval_automorphism_key_gen)
export(multi_eval_sum_key_gen)
export(multi_key_switch_gen)
export(multiparty_decrypt_fusion)
export(multiparty_decrypt_lead)
export(multiparty_decrypt_main)
export(multiparty_key_gen)
export(plaintext_params_hash)
export(recover_shared_key)
export(relinearize)
export(rescale)
export(ring_dimension)
export(serialize_eval_keys)
export(set_ckks_boot_correction_factor)
export(set_ckks_data_type)
export(set_int_vector_value)
export(set_key_gen_level)
export(set_key_tag)
export(set_length)
export(set_level)
export(set_noise_scale_deg)
export(set_num_threads)
export(set_scaling_factor)
export(set_scaling_factor_int)
export(set_slots)
export(set_string_value)
export(share_keys)
export(threshold_decrypt)
export(with_fhe_context)
import(S7)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(methods,new)
useDynLib(openfhe.R, .registration = TRUE)
